@@ -1727,7 +1727,7 @@ tdegtk_draw_common_frame (DRAW_ARGS)
 	state = gtk_theming_engine_get_state(engine);
 	widget = m_widgetLookup.find(cr, path);
 
-	TQString widgetPath(Gtk::gtk_widget_path(widget));
+	TQString widgetPath(Gtk::gtk_widget_path(widget).c_str());
 
 	if (gtk_theming_engine_has_class(engine, GTK_STYLE_CLASS_SCROLLBAR)) {
 #ifdef DRAW_SCROLLBAR_PIECES_INSTEAD_OF_ENTIRE_BAR
